List all epiverse packages
epiverse_packages.RdReturns the names of all packages included in epiverse, read from the package DESCRIPTION file at runtime.

epiverse_packages.RdReturns the names of all packages included in epiverse, read from the package DESCRIPTION file at runtime.